xpcs\_toolkit package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   xpcs_toolkit.fileIO
   xpcs_toolkit.module
   xpcs_toolkit.simplemask
   xpcs_toolkit.utils

Submodules
----------

xpcs\_toolkit.cli\_main module
------------------------------

.. automodule:: xpcsviewer.cli_main
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.cli module
------------------------

.. automodule:: xpcsviewer.cli
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.file\_locator module
----------------------------------

.. automodule:: xpcsviewer.file_locator
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.viewer\_kernel module
-----------------------------------

.. automodule:: xpcsviewer.viewer_kernel
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.viewer\_ui module
-------------------------------

.. note::
   The Viewer UI module is excluded from documentation due to Qt framework dependencies.
   For usage information, see the user guide examples.

xpcs\_toolkit.xpcs\_file module
-------------------------------

.. automodule:: xpcsviewer.xpcs_file
   :members:
   :undoc-members:
   :show-inheritance:

xpcs\_toolkit.xpcs\_viewer module
---------------------------------

.. note::
   The XPCS Viewer GUI module is excluded from documentation due to Qt framework dependencies.
   For usage information, see the user guide examples.

Module contents
---------------

.. automodule:: xpcsviewer
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: XpcsFile, FileLocator, ViewerKernel, ViewerUI, XpcsViewer
   :no-index:
